@@ -81,6 +81,7 @@ class SingleStore(MySQL):
             "!:>": TokenType.NCOLON_GT,
             "::$": TokenType.DCOLONDOLLAR,
             "::%": TokenType.DCOLONPERCENT,
+            "::?": TokenType.DCOLONQMARK,
         }
 
     class Parser(MySQL.Parser):
@@ -253,6 +254,12 @@ class SingleStore(MySQL):
             TokenType.DCOLONPERCENT: lambda self, this, path: build_json_extract_path(
                 exp.JSONExtractScalar, json_type="DOUBLE"
             )([this, exp.Literal.string(path.name)]),
+            TokenType.DCOLONQMARK: lambda self, this, path: self.expression(
+                exp.JSONExists,
+                this=this,
+                path=path.name,
+                from_dcolonqmark=True,
+            ),
         }
         COLUMN_OPERATORS.pop(TokenType.ARROW)
         COLUMN_OPERATORS.pop(TokenType.DARROW)
@@ -452,8 +459,10 @@ class SingleStore(MySQL):
             exp.JSONBExists: lambda self, e: self.func(
                 "BSON_MATCH_ANY_EXISTS", e.this, e.args.get("path")
             ),
-            exp.JSONExists: unsupported_args("passing", "on_condition")(
-                lambda self, e: self.func("JSON_MATCH_ANY_EXISTS", e.this, e.args.get("path"))
+            exp.JSONExists: lambda self, e: (
+                f"{self.sql(e.this)}::?{self.sql(e.args.get('path'))}"
+                if e.args.get("from_dcolonqmark")
+                else self.func("JSON_MATCH_ANY_EXISTS", e.this, e.args.get("path"))
             ),
             exp.JSONObject: unsupported_args(
                 "null_handling", "unique_keys", "return_type", "encoding"
