@@ -18,7 +18,13 @@ if t.TYPE_CHECKING:
 class Schema(abc.ABC):
     """Abstract base class for database schemas"""
 
-    dialect: DialectType
+    @property
+    def dialect(self) -> t.Optional[Dialect]:
+        """
+        Returns None by default. Subclasses that require dialect-specific
+        behavior should override this property.
+        """
+        return None
 
     @abc.abstractmethod
     def add_table(
@@ -222,15 +228,20 @@ class MappingSchema(AbstractMappingSchema, Schema):
         dialect: DialectType = None,
         normalize: bool = True,
     ) -> None:
-        self.dialect = dialect
         self.visible = {} if visible is None else visible
         self.normalize = normalize
+        self._dialect = Dialect.get_or_raise(dialect)
         self._type_mapping_cache: t.Dict[str, exp.DataType] = {}
         self._depth = 0
         schema = {} if schema is None else schema
 
         super().__init__(self._normalize(schema) if self.normalize else schema)
 
+    @property
+    def dialect(self) -> Dialect:
+        """Returns the dialect for this mapping schema."""
+        return self._dialect
+
     @classmethod
     def from_mapping_schema(cls, mapping_schema: MappingSchema) -> MappingSchema:
         return MappingSchema(
@@ -455,8 +466,8 @@ class MappingSchema(AbstractMappingSchema, Schema):
             The resulting expression type.
         """
         if schema_type not in self._type_mapping_cache:
-            dialect = dialect or self.dialect
-            udt = Dialect.get_or_raise(dialect).SUPPORTS_USER_DEFINED_TYPES
+            dialect = Dialect.get_or_raise(dialect) if dialect else self.dialect
+            udt = dialect.SUPPORTS_USER_DEFINED_TYPES
 
             try:
                 expression = exp.DataType.build(schema_type, dialect=dialect, udt=udt)
