@@ -211,7 +211,10 @@ EXPRESSION_METADATA: ExpressionMetadataType = {
             exp.ArrayReverse,
             exp.ArraySlice,
             exp.Filter,
+            exp.HavingMax,
             exp.LastValue,
+            exp.Limit,
+            exp.Order,
             exp.SortArray,
             exp.Window,
         }
@@ -309,4 +312,5 @@ EXPRESSION_METADATA: ExpressionMetadataType = {
     },
     exp.ToMap: {"annotator": lambda self, e: self._annotate_to_map(e)},
     exp.Unnest: {"annotator": lambda self, e: self._annotate_unnest(e)},
+    exp.Subquery: {"annotator": lambda self, e: self._annotate_subquery(e)},
 }
