@@ -19,6 +19,7 @@ class TestSingleStore(Validator):
 
         self.validate_identity("SELECT 1")
         self.validate_identity("SELECT * FROM `users` ORDER BY ALL")
+        self.validate_identity("SELECT ELT(2, 'foo', 'bar', 'baz')")
 
     def test_byte_strings(self):
         self.validate_identity("SELECT e'text'")
@@ -965,3 +966,6 @@ class TestSingleStore(Validator):
         self.validate_identity(
             "CREATE TABLE ComputedColumnConstraint (points INT, score AS (points * 2) PERSISTED BIGINT NOT NULL)"
         )
+
+    def test_dcolonqmark(self):
+        self.validate_identity("SELECT * FROM employee WHERE JSON_MATCH_ANY(payroll::?names)")
