@@ -947,3 +947,8 @@ SELECT * FROM tbl GROUP BY GROUPING SETS ((a + 1, b * 1), c, CUBE (a, b), ROLLUP
 SELECT * FROM tbl GROUP BY GROUPING SETS (GROUPING SETS (course), GROUPING SETS (type), CUBE (a), ROLLUP (b))
 SELECT analyze FROM (SELECT 1 AS analyze)
 SELECT 'Ac' ILIKE 'a%c' ESCAPE NULL
+SELECT CURRENT_DATABASE()
+SELECT CURRENT_SCHEMAS(arg_bool)
+SELECT UNIFORM(1, 10, 5)
+SELECT UNIFORM(1, 10)
+SELECT CURRENT_TIMEZONE()
\ No newline at end of file
