@@ -128,6 +128,14 @@ BIGINT;
 UNIX_MILLIS(CAST('2008-12-25 15:30:00+00' AS TIMESTAMP));
 BIGINT;
 
+# dialect: snowflake
+TO_BINARY('test');
+BINARY;
+
+# dialect: snowflake
+TO_BINARY('test', 'HEX');
+BINARY;
+
 --------------------------------------
 -- Spark2 / Spark3 / Databricks
 --------------------------------------
@@ -408,6 +416,62 @@ DOUBLE;
 EXP(tbl.bignum_col);
 BIGDECIMAL;
 
+# dialect: bigquery
+AVG(1);
+FLOAT64;
+
+# dialect: bigquery
+AVG(5.5);
+FLOAT64;
+
+# dialect: bigquery
+AVG(tbl.bignum_col);
+BIGNUMERIC;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.int_col, tbl.int_col);
+FLOAT64;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.int_col, tbl.bignum_col);
+BIGNUMERIC;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.int_col, tbl.double_col);
+FLOAT64;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.bignum_col, tbl.int_col);
+BIGNUMERIC;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.bignum_col, tbl.bignum_col);
+BIGNUMERIC;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.bignum_col, tbl.double_col);
+FLOAT64;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.double_col, tbl.int_col);
+FLOAT64;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.double_col, tbl.bignum_col);
+FLOAT64;
+
+# dialect: bigquery
+SAFE_DIVIDE(tbl.double_col, tbl.double_col);
+FLOAT64;
+
+# dialect: bigquery
+SAFE.TIMESTAMP(tbl.str_col);
+TIMESTAMPTZ;
+
+# dialect: bigquery
+TIMESTAMP(tbl.str_col);
+TIMESTAMPTZ;
+
 # dialect: bigquery
 CONCAT(tbl.str_col, tbl.str_col);
 STRING;
@@ -796,6 +860,10 @@ STRING;
 MD5('foo');
 BINARY;
 
+# dialect: bigquery
+TO_HEX(MD5('foo'));
+STRING;
+
 # dialect: bigquery
 MAX_BY(tbl.str_col, tbl.bigint_col);
 STRING;
@@ -1036,6 +1104,10 @@ STRING;
 FORMAT('%f %E %f %f', 1.1, 2.2, 3.4, 4.4);
 STRING;
 
+# dialect: bigquery
+NET.HOST('http://example.com');
+STRING;
+
 # dialect: bigquery
 PERCENTILE_CONT(CAST(1 AS NUMERIC), CAST(1 AS NUMERIC)) OVER (ORDER BY 1);
 NUMERIC;
@@ -1528,6 +1600,46 @@ STRING;
 STRING_AGG(tbl.bin_col);
 BINARY;
 
+# dialect: bigquery
+STRING_AGG(DISTINCT tbl.str_col);
+STRING;
+
+# dialect: bigquery
+STRING_AGG(tbl.str_col ORDER BY tbl.str_col);
+STRING;
+
+# dialect: bigquery
+STRING_AGG(DISTINCT tbl.str_col, ',' ORDER BY tbl.str_col);
+STRING;
+
+# dialect: bigquery
+STRING_AGG(DISTINCT tbl.bin_col ORDER BY tbl.bin_col);
+BINARY;
+
+# dialect: bigquery
+STRING_AGG(tbl.str_col, ',' LIMIT 10);
+STRING;
+
+# dialect: bigquery
+STRING_AGG(tbl.str_col, ',' ORDER BY tbl.str_col LIMIT 10);
+STRING;
+
+# dialect: bigquery
+STRING_AGG(DISTINCT tbl.str_col, ',' ORDER BY tbl.str_col LIMIT 10);
+STRING;
+
+# dialect: bigquery
+STRING_AGG(DISTINCT tbl.bin_col ORDER BY tbl.bin_col LIMIT 10);
+BINARY;
+
+# dialect: bigquery
+ARRAY_AGG(tbl.int_col LIMIT 10);
+ARRAY<INT>;
+
+# dialect: bigquery
+ARRAY_AGG(DISTINCT tbl.str_col ORDER BY tbl.str_col LIMIT 10);
+ARRAY<STRING>;
+
 # dialect: bigquery
 DATETIME_TRUNC(DATETIME "2008-12-25 15:30:00", DAY);
 DATETIME;
@@ -1552,6 +1664,46 @@ BIGINT;
 LENGTH(tbl.bin_col);
 BIGINT;
 
+# dialect: bigquery
+IF(TRUE, '2010-01-01', DATE '2020-02-02');
+DATE;
+
+# dialect: bigquery
+IF(TRUE, DATETIME '2010-01-01 00:00:00', '2020-02-02 00:00:00');
+DATETIME;
+
+# dialect: bigquery
+IF(TRUE, '00:00:00', TIME '00:01:00');
+TIME;
+
+# dialect: bigquery
+IF(TRUE, '2010-01-01 00:00:00', TIMESTAMP '2020-02-02 00:00:00');
+TIMESTAMP;
+
+# dialect: bigquery
+COALESCE('2010-01-01', DATE '2020-02-02');
+DATE;
+
+# dialect: bigquery
+COALESCE(DATETIME '2010-01-01 00:00:00', '2020-02-02 00:00:00');
+DATETIME;
+
+# dialect: bigquery
+IFNULL('00:00:00', TIME '00:01:00');
+TIME;
+
+# dialect: bigquery
+IFNULL(TIMESTAMP '2010-01-01 00:00:00', '2020-02-02 00:00:00');
+TIMESTAMP;
+
+# dialect: bigquery
+ANY_VALUE(c2::STRING HAVING MIN c1::INT64);
+STRING;
+
+# dialect: bigquery
+ANY_VALUE(c2::STRING HAVING MAX c1::INT64);
+STRING;
+
 --------------------------------------
 -- Snowflake
 --------------------------------------
@@ -1572,6 +1724,14 @@ DATE;
 ADD_MONTHS(tbl.timestamp_col, -1);
 TIMESTAMP;
 
+# dialect: snowflake
+ARRAY_CONSTRUCT_COMPACT();
+ARRAY;
+
+# dialect: snowflake
+ARRAY_CONSTRUCT_COMPACT(1, null, 2);
+ARRAY;
+
 # dialect: snowflake
 ASIN(tbl.double_col);
 DOUBLE;
@@ -1820,6 +1980,18 @@ BOOLEAN;
 BOOLOR_AGG(tbl.bool_col);
 BOOLEAN;
 
+# dialect: snowflake
+TO_BOOLEAN('true');
+BOOLEAN;
+
+# dialect: snowflake
+TO_BOOLEAN(1);
+BOOLEAN;
+
+# dialect: snowflake
+TO_BOOLEAN(tbl.varchar_col);
+BOOLEAN;
+
 # dialect: snowflake
 ARRAY_AGG(tbl.bin_col);
 ARRAY;
@@ -1840,6 +2012,26 @@ ARRAY;
 ARRAY_AGG(tbl.str_col);
 ARRAY;
 
+# dialect: snowflake
+ARRAY_UNIQUE_AGG(tbl.bin_col);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_UNIQUE_AGG(tbl.bool_col);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_UNIQUE_AGG(tbl.date_col);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_UNIQUE_AGG(tbl.double_col);
+ARRAY;
+
+# dialect: snowflake
+ARRAY_UNIQUE_AGG(tbl.str_col);
+ARRAY;
+
 # dialect: snowflake
 ARRAY_UNION_AGG(tbl.array_col);
 ARRAY;
@@ -1932,6 +2124,14 @@ DATE;
 CAST(1.5 AS DECFLOAT);
 DECFLOAT;
 
+# dialect: snowflake
+CAST(1 AS VARCHAR);
+VARCHAR;
+
+# dialect: snowflake
+CAST('123' AS INT);
+INT;
+
 # dialect: snowflake
 COALESCE(TRUE, FALSE);
 BOOLEAN;
@@ -2096,6 +2296,78 @@ TIMESTAMPTZ;
 CONVERT_TIMEZONE('America/Los_Angeles', 'America/New_York', '2024-08-06 09:10:00.000');
 TIMESTAMPNTZ;
 
+# dialect: snowflake
+CURRENT_ACCOUNT();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_ACCOUNT_NAME();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_AVAILABLE_ROLES();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_CLIENT();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_IP_ADDRESS();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_DATABASE();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_SCHEMAS();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_SECONDARY_ROLES();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_SESSION();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_STATEMENT();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_VERSION();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_TRANSACTION();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_WAREHOUSE();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_ORGANIZATION_USER();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_REGION();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_ROLE();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_ROLE_TYPE();
+VARCHAR;
+
+# dialect: snowflake
+CURRENT_ORGANIZATION_NAME();
+VARCHAR;
+
 # dialect: snowflake
 DATEDIFF('year', tbl.date_col, tbl.date_col);
 INT;
@@ -2796,10 +3068,122 @@ DOUBLE;
 REGR_AVGX(tbl.double_col, tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+REGR_AVGX(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_AVGX(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
 # dialect: snowflake
 REGR_AVGY(tbl.double_col, tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+REGR_AVGY(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_AVGY(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_COUNT(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_COUNT(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_COUNT(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_COUNT(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_INTERCEPT(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_INTERCEPT(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_INTERCEPT(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_INTERCEPT(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_R2(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_R2(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_R2(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_R2(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_SXX(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SXX(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SXX(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SXX(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_SXY(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SXY(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SXY(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SXY(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_SYY(tbl.double_col, tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SYY(tbl.double_col, tbl.double_col) OVER (PARTITION BY 1);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SYY(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_SYY(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
 # dialect: snowflake
 REGR_SLOPE(tbl.double_col, tbl.double_col);
 DOUBLE;
@@ -2812,14 +3196,46 @@ DOUBLE;
 REGR_SLOPE(tbl.int_col, tbl.int_col);
 DOUBLE;
 
+# dialect: snowflake
+REGR_SLOPE(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+REGR_VALX(NULL, 2.0);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALX(NULL, NULL);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALX(2.0, NULL);
+DOUBLE;
+
 # dialect: snowflake
 REGR_VALX(1.0, 2.0);
 DOUBLE;
 
+# dialect: snowflake
+REGR_VALX(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALX(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
 # dialect: snowflake
 REGR_VALY(1.0, 2.0);
 DOUBLE;
 
+# dialect: snowflake
+REGR_VALY(tbl.int_col, tbl.int_col);
+DOUBLE;
+
+# dialect: snowflake
+REGR_VALY(tbl.decfloat_col, tbl.decfloat_col);
+DECFLOAT;
+
 # dialect: snowflake
 'foo' REGEXP 'bar';
 BOOLEAN;
@@ -3172,6 +3588,158 @@ DECFLOAT;
 TRY_TO_DECFLOAT('invalid');
 DECFLOAT;
 
+# dialect: snowflake
+TRY_TO_BINARY('48656C6C6F');
+BINARY;
+
+# dialect: snowflake
+TRY_TO_BINARY('48656C6C6F', 'HEX');
+BINARY;
+
+# dialect: snowflake
+TRY_TO_BOOLEAN('true');
+BOOLEAN;
+
+# dialect: snowflake
+TO_DATE('2024-01-31');
+DATE;
+
+# dialect: snowflake
+TO_DATE('2024-01-31', 'AUTO');
+DATE;
+
+# dialect: snowflake
+TRY_TO_DATE('2024-01-31');
+DATE;
+
+# dialect: snowflake
+TRY_TO_DATE('2024-01-31', 'AUTO');
+DATE;
+
+# dialect: snowflake
+TO_DECIMAL('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_DECIMAL('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_DECIMAL('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_DECIMAL('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_DECIMAL('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_DECIMAL('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_DOUBLE('123.456');
+DOUBLE;
+
+# dialect: snowflake
+TO_DOUBLE('123.456', '999.99');
+DOUBLE;
+
+# dialect: snowflake
+TRY_TO_DOUBLE('123.456');
+DOUBLE;
+
+# dialect: snowflake
+TRY_TO_DOUBLE('123.456', '999.99');
+DOUBLE;
+
+# dialect: snowflake
+TO_FILE(tbl.obj_col);
+FILE;
+
+# dialect: snowflake
+TO_FILE('file.csv');
+FILE;
+
+# dialect: snowflake
+TO_FILE('file.csv', '/relativepath/');
+FILE;
+
+# dialect: snowflake
+TRY_TO_FILE(tbl.obj_col);
+FILE;
+
+# dialect: snowflake
+TRY_TO_FILE('file.csv');
+FILE;
+
+# dialect: snowflake
+TRY_TO_FILE('file.csv', '/relativepath/');
+FILE;
+
+# dialect: snowflake
+TO_NUMBER('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_NUMBER('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_NUMBER('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMBER('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMBER('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMBER('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMERIC('123.45');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMERIC('123.45', '999.99');
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TRY_TO_NUMERIC('123.45', '999.99', 10, 2);
+DECIMAL(38, 0);
+
+# dialect: snowflake
+TO_TIME('12:30:00');
+TIME;
+
+# dialect: snowflake
+TO_TIME('12:30:00', 'AUTO');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIME('12:30:00');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIME('12:30:00', 'AUTO');
+TIME;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP('2024-01-15 12:30:00');
+TIMESTAMP;
+
+# dialect: snowflake
+TRY_TO_TIMESTAMP('2024-01-15 12:30:00', 'AUTO');
+TIMESTAMP;
+
 # dialect: snowflake
 ABS(CAST(-123.456 AS DECFLOAT));
 DECFLOAT;
@@ -3700,6 +4268,18 @@ INT;
 PERCENTILE_DISC(0.25) WITHIN GROUP (ORDER BY tbl.double_col);
 DOUBLE;
 
+# dialect: snowflake
+PERCENTILE_CONT(0.25) WITHIN GROUP (ORDER BY tbl.int_col);
+INT;
+
+# dialect: snowflake
+PERCENTILE_CONT(0.5) WITHIN GROUP (ORDER BY tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+PERCENTILE_CONT(0.75) WITHIN GROUP (ORDER BY tbl.bigint_col) OVER (PARTITION BY 1);
+BIGINT;
+
 # dialect: snowflake
 PARSE_IP('192.168.1.1', 'INET');
 OBJECT;
@@ -3768,6 +4348,26 @@ DOUBLE;
 APPROX_PERCENTILE(tbl.int_col, 0.9) OVER (PARTITION BY 1);
 DOUBLE;
 
+# dialect: snowflake
+APPROX_PERCENTILE_COMBINE(tbl.state_col);
+OBJECT;
+
+# dialect: snowflake
+APPROX_PERCENTILE_ACCUMULATE(tbl.bigint_col);
+OBJECT;
+
+# dialect: snowflake
+APPROX_PERCENTILE_ACCUMULATE(tbl.double_col);
+OBJECT;
+
+# dialect: snowflake
+APPROX_PERCENTILE_ACCUMULATE(tbl.int_col);
+OBJECT;
+
+# dialect: snowflake
+APPROX_PERCENTILE_ESTIMATE(tbl.state_col, 0.5);
+DOUBLE;
+
 # dialect: snowflake
 APPROX_TOP_K_ACCUMULATE(tbl.str_col, 10);
 OBJECT;
@@ -3880,6 +4480,142 @@ DECIMAL(10, 2);
 MIN(tbl.bigint_col) OVER (PARTITION BY 1);
 BIGINT;
 
+# dialect: snowflake
+VECTOR_COSINE_SIMILARITY([1,2,3], [4,5,6]);
+DOUBLE;
+
+# dialect: snowflake
+VECTOR_INNER_PRODUCT([1,2,3], [4,5,6]);
+DOUBLE;
+
+# dialect: snowflake
+VECTOR_L1_DISTANCE([1,2,3], [4,5,6]);
+DOUBLE;
+
+# dialect: snowflake
+VECTOR_L2_DISTANCE([1,2,3], [4,5,6]);
+DOUBLE;
+
+# dialect: snowflake
+ZIPF(1, 10, RANDOM());
+BIGINT;
+
+# dialect: snowflake
+ZIPF(2, 100, 1234);
+BIGINT;
+
+# dialect: snowflake
+XMLGET(PARSE_XML('<root><level2>content</level2></root>'), 'level2');
+OBJECT;
+
+# dialect: snowflake
+XMLGET(PARSE_XML('<root><item>a</item><item>b</item></root>'), 'item', 1);
+OBJECT;
+
+# dialect: snowflake
+MODE(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+MODE(tbl.date_col);
+DATE;
+
+# dialect: snowflake
+MODE(tbl.timestamp_col);
+TIMESTAMP;
+
+# dialect: snowflake
+MODE(tbl.bool_col);
+BOOLEAN;
+
+# dialect: snowflake
+MODE(CAST(100 AS DECIMAL(10,2)));
+DECIMAL(10, 2);
+
+# dialect: snowflake
+MODE(tbl.bigint_col) OVER (PARTITION BY 1);
+BIGINT;
+
+# dialect: snowflake
+MODE(CAST(NULL AS INT));
+INT;
+
+# dialect: snowflake
+MODE(tbl.str_col) OVER (PARTITION BY tbl.int_col);
+VARCHAR;
+
+# dialect: snowflake
+VAR_SAMP(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+VAR_SAMP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+VAR_SAMP(tbl.int_col);
+NUMBER(38, 6);
+
+# dialect: snowflake
+VARIANCE_SAMP(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+VARIANCE_SAMP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+VARIANCE_SAMP(tbl.int_col);
+NUMBER(38, 6);
+
+# dialect: snowflake
+VARIANCE(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+VARIANCE(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+VARIANCE(tbl.int_col);
+NUMBER(38, 6);
+
+# dialect: snowflake
+VAR_POP(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+VAR_POP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+VAR_POP(tbl.int_col);
+NUMBER(38, 6);
+
+# dialect: snowflake
+VARIANCE_POP(tbl.decfloat_col);
+DECFLOAT;
+
+# dialect: snowflake
+VARIANCE_POP(tbl.double_col);
+DOUBLE;
+
+# dialect: snowflake
+VARIANCE_POP(tbl.int_col);
+NUMBER(38, 6);
+
+# dialect: snowflake
+VARIANCE_POP(1::NUMBER(38, 6));
+NUMBER(38, 12);
+
+# dialect: snowflake
+VARIANCE_POP(1::NUMBER(38, 15));
+NUMBER(38, 15);
+
+# dialect: snowflake
+VARIANCE_POP(1::NUMBER(30, 5));
+NUMBER(38, 12);
+
 --------------------------------------
 -- T-SQL
 --------------------------------------
