@@ -36,14 +36,26 @@ class TestGenerator(unittest.TestCase):
         )
 
     def test_identify(self):
-        assert parse_one("x").sql(identify=True) == '"x"'
-        assert parse_one("x").sql(identify="always") == '"x"'
-        assert parse_one("X").sql(identify="always") == '"X"'
-        assert parse_one("x").sql(identify="safe") == '"x"'
-        assert parse_one("X").sql(identify="safe") == "X"
-        assert parse_one("x as 1").sql(identify="safe") == '"x" AS "1"'
-        assert parse_one("X as 1").sql(identify="safe") == 'X AS "1"'
+        self.assertEqual(parse_one("x").sql(identify=True), '"x"')
+        self.assertEqual(parse_one("x").sql(identify=False), "x")
+        self.assertEqual(parse_one("X").sql(identify=True), '"X"')
+        self.assertEqual(parse_one('"x"').sql(identify=False), '"x"')
+        self.assertEqual(parse_one("x").sql(identify="safe"), '"x"')
+        self.assertEqual(parse_one("X").sql(identify="safe"), "X")
+        self.assertEqual(parse_one("x as 1").sql(identify="safe"), '"x" AS "1"')
+        self.assertEqual(parse_one("X as 1").sql(identify="safe"), 'X AS "1"')
 
     def test_generate_nested_binary(self):
         sql = "SELECT 'foo'" + (" || 'foo'" * 1000)
         self.assertEqual(parse_one(sql).sql(copy=False), sql)
+
+    def test_overlap_operator(self):
+        for op in ("&<", "&>"):
+            with self.subTest(op=op):
+                input_sql = f"SELECT '[1,10]'::int4range {op} '[5,15]'::int4range"
+                expected_sql = (
+                    f"SELECT CAST('[1,10]' AS INT4RANGE) {op} CAST('[5,15]' AS INT4RANGE)"
+                )
+                ast = parse_one(input_sql, read="postgres")
+                self.assertEqual(ast.sql(), expected_sql)
+                self.assertEqual(ast.sql("postgres"), expected_sql)
